// (c) Copyright Open Text Corporation

using System;
using System.Xml.Serialization;
using System.Collections;
using OpenText.Livelink.Service.Core;
using OpenText.ContentServer.API;

namespace OpenText.Livelink.Service.Hello
{

/// <summary>
/// <para>HelloGreeting is a sample SDO that holds a friendly greeting.</para>
/// </summary>
/// <version>2013-08-26</version>
[Serializable]
[XmlType(Namespace = "urn:Hello.service.livelink.opentext.com")]
public class HelloGreeting : ServiceDataObject
{
	private static Log sLog = LogFactory.GetLog( "OpenText.Livelink.Service.Hello.HelloGreeting" );

	private DateTime fGreetingDate;
	private string fGreetingMessage;

	/// <summary>
	/// <para>Gets or sets the Date of the greeting.</para>
	/// </summary>
	[XmlElement(IsNullable = false)]
	public DateTime GreetingDate
	{
		get
		{
			return fGreetingDate;
		}

		set
		{
			fGreetingDate = value;
		}
	}

	/// <summary>
	/// <para>Gets or sets the greeting message.</para>
	/// </summary>
	[XmlElement(IsNullable = false)]
	public string GreetingMessage
	{
		get
		{
			return fGreetingMessage;
		}

		set
		{
			fGreetingMessage = value;
		}
	}

	public override void load( LLValue value )
	{
		String		featureName = null;

		// Load the parent
		base.load( value );

		try
		{

			featureName = "GreetingDate";
			fGreetingDate = SDOUtil.getDateNETValue( value.toValue( "GreetingDate" ), "GreetingDate" );

			featureName = "GreetingMessage";
			fGreetingMessage = SDOUtil.getStringValue( value.toValue( "GreetingMessage" ), "GreetingMessage" );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error loading HelloGreeting." + featureName;
			sLog.Error( errMsg );
			sLog.Error( "  LAPI error: " + ex.Message, ex );
			throw new ServiceException( errMsg );
		}
		catch ( ServiceException ex )
		{
			String		errMsg = "Error loading HelloGreeting." + featureName;
			sLog.Error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
		catch ( Exception ex )
		{
			String		errMsg = "Error loading HelloGreeting." + featureName;
			sLog.Error( errMsg );
			throw new ServiceException( errMsg, ex );
		}
	}

	public override LLValue toLLValue()
	{
		LLValue		value = new LLValue();

		value.setAssoc();

		try
		{
			SDOUtil.setPrimitiveValue( value, "GreetingDate", fGreetingDate, LLValue.LL_DATE );
			SDOUtil.setPrimitiveValue( value, "GreetingMessage", fGreetingMessage, LLValue.LL_STRING );
		}
		catch ( LLIllegalOperationException ex )
		{
			String		errMsg = "Error converting HelloGreeting to an LLValue";
			sLog.Error( errMsg );
			sLog.Error( "  LAPI error: " + ex.Message, ex );
			throw new ServiceException( errMsg );
		}

		LLValue	parent = base.toLLValue();

		if ( parent != null )
		{
			IEnumerator nameEnum = parent.GetKeyEnumerator();
			while ( nameEnum.MoveNext() )
			{
				DictionaryEntry entry = (DictionaryEntry) nameEnum.Current;
				String name = ((LLName)entry.Key).toString();
				value.add( name, parent.toValue( name ) );
			}
		}

		// override any _SDOName set in the parent
		value.add( "_SDOName", new LLValue( "Hello.HelloGreeting" ) );

		return value;
	}

	public override string ToString()
	{
		System.Text.StringBuilder	sb = new System.Text.StringBuilder();

		sb.Append( "HelloGreeting[" );
		sb.Append( "fGreetingDate=" ).Append( fGreetingDate ).Append( ",");
		sb.Append( "fGreetingMessage=" ).Append( fGreetingMessage ).Append( ",");
		sb.Append( "]" );

		// Output the parent
		sb.Append( base.ToString() );

		return sb.ToString();
	}
}
}
