// (c) Copyright Open Text Corporation

using System;
using System.Configuration;
using System.IO;
using System.Xml.Serialization;
using OpenText.Livelink.Service.Core;
using OpenText.ContentServer.API;

namespace OpenText.Livelink.Service.Hello
{

/// <summary>
/// <para>HelloWorld defines the service that represents a prototypical Hello World! service.</para>
/// </summary>
/// <version>2013-08-26</version>
public class HelloWorld : OpenText.Livelink.Service.Core.Service, IHelloWorld
{
	private static Log sLog = LogFactory.GetLog( "OpenText.Livelink.Service.Hello.HelloWorld" );
	private static string SERVICE_NAME = "HelloWorld";
	public HelloWorld()
	{
	}

	/// <summary>
	/// Get the Hello World message
	/// </summary>
	/// <returns>Returns the hello world message</returns>
	public HelloMessage GetMessage()
	{
		HelloMessage		retval = null;
		LLSession			lapiSession;
		LAPI_SERVICE		service;

		LLValue				args = new LLValue();
		LLValue				result = new LLValue();
		LLValue				env = getLapiEnvironment();

		args.setAssoc();

		if ( sLog.TraceEnabled )
		{
			sLog.Trace( "begin: HelloWorld.GetMessage()" );
		}

		try
		{

			lapiSession = getLapiSession();
			service = new LAPI_SERVICE( lapiSession );

			int status = service.InvokeService( SERVICE_NAME, "GetMessage", args, env, result );

			if ( status != 0 )
			{
				ExceptionUtil.throwLivelinkException( lapiSession.getStatus(), lapiSession.getStatusMessage(), lapiSession.getErrMsg(), lapiSession.getApiError(), "urn:Hello.service.livelink.opentext.com" );
			}
			else if ( result.isDefined() )
			{
				retval = (HelloMessage) SDOUtil.getSDOValue( "OpenText.Livelink.Service.Hello", result );
			}
		}
		catch ( Exception ex )
		{
			ExceptionUtil.handleException( ex );
		}

		if ( sLog.TraceEnabled )
		{
			sLog.Trace( "end:   HelloWorld.GetMessage()" );
		}

		return retval;
	}

}
}
